<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Jelölő stíéusa</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Stílusos mód</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klasszikus mód</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Középre igazított mód</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Folyamatosan látható</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Maradjon rejtve</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Dokkoló beállításai</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>